@@ -3,7 +3,6 @@ package Module::Install::PRIVATE::Fix_Standard_Tests;
 
 use strict;
 use warnings;
-use File::Slurper qw(read_text write_text);
 
 use vars qw( @ISA $VERSION );
 
@@ -17,6 +16,13 @@ $VERSION = sprintf "%d.%02d%02d", q/0.1.0/ =~ /(\d+)/g;
 sub fix_standard_tests {
   my ($self, $script_name, @args) = @_;
 
+  $self->perl_version('5.005');
+
+  $self->include_deps('File::Slurper', 0);
+
+  require File::Slurper;
+  File::Slurper->import('read_text', 'write_text');
+
   # Update compile test
   {
     my $test = read_text('t/000_standard__compile.t', undef, 1);
