@@ -1,7 +1,7 @@
 package Test::ConfigureGrepmail;
 
 use strict;
-use File::Slurp;
+use File::Slurper qw(read_text write_text);
 
 sub Set_Caching_And_Grep
 {
@@ -9,12 +9,12 @@ sub Set_Caching_And_Grep
   my $enable_caching = shift;
   my $enable_grep = shift;
 
-  my $code = read_file($filename);
+  my $code = read_text($filename, undef, 1);
 
   $code =~ s/^\$USE_CACHING = (\d+);/\$USE_CACHING = $enable_caching;/m;
   $code =~ s/^\$USE_GREP = (\d+);/\$USE_GREP = $enable_grep;/m;
 
-  write_file($filename, $code);
+  write_text($filename, $code, undef, 1);
 }
 
 # --------------------------------------------------------------------------
@@ -24,7 +24,7 @@ sub Set_Cache_File
   my $filename = shift;
   my $cache_file = shift;
 
-  my $code = read_file($filename);
+  my $code = read_text($filename, undef, 1);
 
   if ($code =~ /(Mail::Mbox::MessageParser::SETUP_CACHE\( {.*?} *\))/s)
   {
@@ -36,7 +36,7 @@ sub Set_Cache_File
     $code =~ s/\Q$original_cache_setup\E/$new_cache_setup/;
   }
 
-  write_file($filename, $code);
+  write_text($filename, $code, undef, 1);
 }
 
 1;
